#ifdef USE_SMB_BRANCH
void
SMBGetFile (GtkTreeView *treeview, char *target,GList *list);
void
SMBDropFile (GtkTreeView *treeview,tree_entry_t *t_en, 
		GtkTreeIter *iter,char *tmpfile);
GList *
SMBrmFile (GtkTreeView *treeview,char *remote_location,
	       char *remote_pass,char *tmpfile,GList *reference_list);
void
SMBmkdir (GtkTreeView *treeview,tree_entry_t *t_en,
	       GtkTreeIter *iter,gchar *newdir);
G_MODULE_EXPORT
const gchar *SMBget_cache_file(GtkTreeView *treeview, tree_entry_t *en);
G_MODULE_EXPORT
const gchar *get_netfile_cache_dir(void);
#endif

